@@ -51,24 +51,6 @@
 #define NAUTILUS_LINK_MOUNT_TAG 	"FSDevice"
 #define NAUTILUS_LINK_HOME_TAG 		"X-nautilus-home"
 
-static const char *
-get_tag (NautilusLinkType type)
-{
-	switch (type) {
-	default:
-		g_assert_not_reached ();
-		/* fall through */
-	case NAUTILUS_LINK_GENERIC:
-		return NAUTILUS_LINK_GENERIC_TAG;
-	case NAUTILUS_LINK_TRASH:
-		return NAUTILUS_LINK_TRASH_TAG;
-	case NAUTILUS_LINK_MOUNT:
-		return NAUTILUS_LINK_MOUNT_TAG;
-	case NAUTILUS_LINK_HOME:
-		return NAUTILUS_LINK_HOME_TAG;
-	}
-}
-
 static char *
 slurp_key_string (const char *uri,
 		  const char *keyname,
@@ -97,13 +79,13 @@ slurp_key_string (const char *uri,
 
 gboolean
 nautilus_link_desktop_file_local_create (const char        *directory_uri,
-					 const char        *file_name,
+					 const char        *base_name,
 					 const char        *display_name,
 					 const char        *image,
 					 const char        *target_uri,
 					 const GdkPoint    *point,
 					 int                screen,
-					 NautilusLinkType   type)
+					 gboolean           unique_filename)
 {
 	char *uri, *contents, *escaped_name;
 	GnomeDesktopItem *desktop_item;
@@ -111,24 +93,28 @@ nautilus_link_desktop_file_local_create (const char        *directory_uri,
 	NautilusFileChangesQueuePosition item;
 
 	g_return_val_if_fail (directory_uri != NULL, FALSE);
-	g_return_val_if_fail (file_name != NULL, FALSE);
+	g_return_val_if_fail (base_name != NULL, FALSE);
 	g_return_val_if_fail (display_name != NULL, FALSE);
 	g_return_val_if_fail (target_uri != NULL, FALSE);
 
-	escaped_name = gnome_vfs_escape_string (file_name);
-	uri = g_strdup_printf ("%s/%s", directory_uri, escaped_name);
-	g_free (escaped_name);
+	if (unique_filename) {
+		uri = nautilus_ensure_unique_file_name (directory_uri,
+							base_name, ".desktop");
+	} else {
+		escaped_name = gnome_vfs_escape_string (base_name);
+		uri = g_strdup_printf ("%s/%s.desktop", directory_uri, escaped_name);
+		g_free (escaped_name);
+	}
 
 	contents = g_strdup_printf ("[Desktop Entry]\n"
 				    "Encoding=UTF-8\n"
 				    "Name=%s\n"
-				    "Type=%s\n"
+				    "Type=Link\n"
 				    "URL=%s\n"
 				    "%s%s\n",
 				    display_name,
-				    get_tag (type),
 				    target_uri,
-				    image != NULL ? "X-Nautilus-Icon=" : "",
+				    image != NULL ? "Icon=" : "",
 				    image != NULL ? image : "");
 	
 	desktop_item = gnome_desktop_item_new_from_string (uri,
@@ -174,25 +160,6 @@ nautilus_link_desktop_file_local_create (const char        *directory_uri,
 	return TRUE;
 }
 
-gboolean
-nautilus_link_desktop_file_local_set_icon (const char *uri,
-					   const char *icon_name)
-{
-	GnomeDesktopItem *desktop_file;
-	gboolean success;
-
-	desktop_file = gnome_desktop_item_new_from_uri (uri, 0, NULL);
-	if (desktop_file == NULL) {
-		return FALSE;
-	}
-
-	gnome_desktop_item_set_string (desktop_file, "X-Nautilus-Icon", icon_name);
-	success = gnome_desktop_item_save (desktop_file, NULL, FALSE, NULL);
-	gnome_desktop_item_unref (desktop_file);
-	
-	return success;
-}
-
 gboolean
 nautilus_link_desktop_file_local_set_text (const char *uri,
 					   const char *text)
@@ -246,56 +213,6 @@ nautilus_link_desktop_file_local_get_additional_text (const char *path)
 #endif
 }
 
-NautilusLinkType
-nautilus_link_desktop_file_local_get_link_type (const char *path)
-{
-	char *type;
-	NautilusLinkType retval;
-
-	type = slurp_key_string (path, "Type", FALSE);
-
-	if (type == NULL) {
-		return NAUTILUS_LINK_GENERIC;
-	}
-	if (strcmp (type, NAUTILUS_LINK_HOME_TAG) == 0) {
-		retval = NAUTILUS_LINK_HOME;
-	} else if (strcmp (type, NAUTILUS_LINK_MOUNT_TAG) == 0) {
-		retval = NAUTILUS_LINK_MOUNT;
-	} else if (strcmp (type, NAUTILUS_LINK_TRASH_TAG) == 0) {
-		retval = NAUTILUS_LINK_TRASH;
-	} else {
-		retval = NAUTILUS_LINK_GENERIC;
-	}
-
-	g_free (type);
-	return retval;
-}
-
-gboolean
-nautilus_link_desktop_file_local_is_utf8 (const char       *uri)
-{
-	char *contents;
-	int file_size;
-	gboolean retval;
-
-	if (eel_read_entire_file (uri,
-				  &file_size,
-				  &contents) != GNOME_VFS_OK) {
-		return FALSE;
-	}
-	
-	if (g_strstr_len (contents, file_size, "Encoding=UTF-8\n") != NULL) {
-		retval = TRUE;
-	} else {
-		retval = FALSE;
-	}
-
-	g_free (contents);
-	
-	return retval;
-}
-
-
 
 static char *
 nautilus_link_desktop_file_get_link_uri_from_desktop (GnomeDesktopItem *desktop_file)
