@@ -35,6 +35,8 @@
 #define FM_IS_LIST_VIEW(obj)		(GTK_CHECK_TYPE ((obj), FM_TYPE_LIST_VIEW))
 #define FM_IS_LIST_VIEW_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), FM_TYPE_LIST_VIEW))
 
+#define FM_LIST_VIEW_ID "OAFIID:Nautilus_File_Manager_List_View"
+
 typedef struct FMListViewDetails FMListViewDetails;
 
 typedef struct {
@@ -47,5 +49,6 @@ typedef struct {
 } FMListViewClass;
 
 GType fm_list_view_get_type (void);
+void  fm_list_view_register (void);
 
 #endif /* FM_LIST_VIEW_H */
