@@ -487,11 +487,12 @@ compare_rows (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer call
 	NautilusFile *file_a, *file_b;
 	int result;
 
+	/* Dummy rows are always first */
 	if (a->user_data == NULL) {
 		return -1;
 	}
 	else if (b->user_data == NULL) {
-		return -1;
+		return 1;
 	}
 
 	/* don't sort root nodes */
@@ -1235,6 +1236,10 @@ create_tree (FMTreeView *view)
 	view->details->tree_widget = GTK_TREE_VIEW
 		(gtk_tree_view_new_with_model (GTK_TREE_MODEL (view->details->sort_model)));
 	g_object_unref (view->details->sort_model);
+
+	gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (view->details->sort_model),
+						 compare_rows, view, NULL);
+
 	g_signal_connect_object
 		(view->details->child_model, "row_loaded",
 		 G_CALLBACK (row_loaded_callback),
@@ -1262,9 +1267,6 @@ create_tree (FMTreeView *view)
 	
 	g_object_unref (view->details->child_model);
 
-	gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (view->details->sort_model),
-						 compare_rows, view, NULL);
-
 	gtk_tree_view_set_headers_visible (view->details->tree_widget, FALSE);
 
 	view->details->drag_dest = 
