@@ -31,6 +31,7 @@
 #include "nautilus-actions.h"
 #include "nautilus-application.h"
 #include "nautilus-location-bar.h"
+#include "nautilus-pathbar.h"
 #include "nautilus-main.h"
 #include "nautilus-window-private.h"
 #include "nautilus-zoom-control.h"
@@ -58,7 +59,6 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-monitor.h>
-#include <libnautilus-private/nautilus-theme.h>
 #include <libnautilus-private/nautilus-view-factory.h>
 #include <libnautilus-private/nautilus-window-info.h>
 
@@ -123,7 +123,7 @@ set_displayed_location (NautilusWindow *window, const char *location)
                 recreate = TRUE;
         } else {
                 bookmark_uri = nautilus_bookmark_get_uri (window->current_location_bookmark);
-                recreate = !eel_uris_match (bookmark_uri, location);
+                recreate = !gnome_vfs_uris_match (bookmark_uri, location);
                 g_free (bookmark_uri);
         }
         
@@ -146,7 +146,7 @@ check_bookmark_location_matches (NautilusBookmark *bookmark, const char *uri)
 	char *bookmark_uri;
 
 	bookmark_uri = nautilus_bookmark_get_uri (bookmark);
-	if (!eel_uris_match (uri, bookmark_uri)) {
+	if (!gnome_vfs_uris_match (uri, bookmark_uri)) {
 		g_warning ("bookmark uri is %s, but expected %s", bookmark_uri, uri);
 	}
 	g_free (bookmark_uri);
@@ -254,7 +254,7 @@ handle_go_elsewhere (NautilusWindow *window, const char *location)
                          * This also avoids a problem where set_displayed_location
                          * didn't update last_location_bookmark since the uri didn't change.
                          */
-                        if (!eel_uris_match (window->details->location, location)) {
+                        if (!gnome_vfs_uris_match (window->details->location, location)) {
                                 /* Store bookmark for current location in back list, unless there is no current location */
                                 check_last_bookmark_location_matches_window (window);
                                 /* Use the first bookmark in the history list rather than creating a new one. */
@@ -348,10 +348,12 @@ viewed_file_changed_callback (NautilusFile *file,
                         update_up_button (window);
 #if !NEW_UI_COMPLETE
                         if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
-                                /* Change the location bar to match the current location. */
+                                /* Change the location bar and path bar to match the current location. */
                                 nautilus_navigation_bar_set_location
                                         (NAUTILUS_NAVIGATION_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->navigation_bar),
                                          window->details->location);
+				nautilus_path_bar_set_path (NAUTILUS_PATH_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->path_bar),
+					    window->details->location);
                         }                  
                         if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
                                 /* Change the location button to match the current location. */
@@ -566,40 +568,52 @@ nautilus_window_get_view_label (NautilusWindow *window)
 	return g_strdup (info->label);
 }
 
-static void
-report_content_view_failure_to_user_internal (NautilusWindow *window,
-                                     	      NautilusView *view,
-                                     	      const char *message,
-					      const char *detail)
+char *
+nautilus_window_get_view_error_label (NautilusWindow *window)
 {
-	char *label;
+	const NautilusViewInfo *info;
 
-	label = nautilus_window_get_view_label (window);
-	message = g_strdup_printf (message, label);
-	eel_show_error_dialog (message, detail, _("View Failed"), GTK_WINDOW (window));
-	g_free (label);
+	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
+
+	return g_strdup (info->error_label);
+}
+
+char *
+nautilus_window_get_view_startup_error_label (NautilusWindow *window)
+{
+	const NautilusViewInfo *info;
+
+	info = nautilus_view_factory_lookup (nautilus_window_get_content_view_id (window));
+
+	return g_strdup (info->startup_error_label);
 }
 
 static void
 report_current_content_view_failure_to_user (NautilusWindow *window,
                                      	     NautilusView *view)
 {
-	report_content_view_failure_to_user_internal 
-		(window,
-		 view,
-		 _("The %s view encountered an error and can't continue."),
-		 _("You can choose another view or go to a different location."));
+	char *message;
+
+	message = nautilus_window_get_view_startup_error_label (window);
+	eel_show_error_dialog (message,
+			       _("You can choose another view or go to a different location."),
+			       _("View Failed"),
+			       GTK_WINDOW (window));
+	g_free (message);
 }
 
 static void
 report_nascent_content_view_failure_to_user (NautilusWindow *window,
                                      	     NautilusView *view)
 {
-	report_content_view_failure_to_user_internal 
-		(window,
-		 view,
-		 _("The %s view encountered an error while starting up."),
-		 _("The location cannot be displayed with this viewer."));
+	char *message;
+
+	message = nautilus_window_get_view_error_label (window);
+	eel_show_error_dialog (message,
+			       _("The location cannot be displayed with this viewer."),
+			       _("View Failed"),
+			       GTK_WINDOW (window));
+	g_free (message);
 }
 
 
@@ -906,9 +920,9 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 				   in which case going home would cause an infinite loop, so we
 				   better test for that */
 				
-				if (!eel_uris_match (location, "file:///")) {
+				if (!gnome_vfs_uris_match (location, "file:///")) {
 					home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
-					if (!eel_uris_match (home_uri, location)) {	
+					if (!gnome_vfs_uris_match (home_uri, location)) {	
 						nautilus_window_go_home (NAUTILUS_WINDOW (window));
 					} else {
 						/* the last fallback is to go to a known place that can't be deleted! */
@@ -1034,8 +1048,6 @@ load_new_location (NautilusWindow *window,
 	g_assert (NAUTILUS_IS_WINDOW (window));
 	g_assert (location != NULL);
 
-        set_displayed_location (window, location);
-
 	selection_copy = eel_g_str_list_copy (selection);
 
 	view = NULL;
@@ -1106,11 +1118,6 @@ location_has_really_changed (NautilusWindow *window)
 
         free_location_change (window);
 
-        nautilus_window_update_title (window);
-	nautilus_window_update_icon (window);
-
-	gtk_widget_show (GTK_WIDGET (window));
-
 	if (location_copy != NULL) {
 		g_signal_emit_by_name (window, "loading_uri",
 				       location_copy);
@@ -1127,7 +1134,9 @@ update_for_new_location (NautilusWindow *window)
         
         new_location = window->details->pending_location;
         window->details->pending_location = NULL;
-        
+
+	set_displayed_location (window, new_location);
+
         update_history (window, window->details->location_change_type, new_location);
                 
         /* Set the new location. */
@@ -1165,10 +1174,11 @@ update_for_new_location (NautilusWindow *window)
                 nautilus_navigation_window_allow_back (NAUTILUS_NAVIGATION_WINDOW (window), NAUTILUS_NAVIGATION_WINDOW (window)->back_list != NULL);
                 nautilus_navigation_window_allow_forward (NAUTILUS_NAVIGATION_WINDOW (window), NAUTILUS_NAVIGATION_WINDOW (window)->forward_list != NULL);
 
-                /* Change the location bar to match the current location. */
+                /* Change the location bar and path bar to match the current location. */
                 nautilus_navigation_bar_set_location (NAUTILUS_NAVIGATION_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->navigation_bar),
                                                       window->details->location);
-
+		nautilus_path_bar_set_path (NAUTILUS_PATH_BAR (NAUTILUS_NAVIGATION_WINDOW (window)->path_bar),
+					    window->details->location);
 		nautilus_navigation_window_load_extension_toolbar_items (NAUTILUS_NAVIGATION_WINDOW (window));
         }
         
@@ -1426,7 +1436,11 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 		detail_message = g_strdup
 			(_("Check that an SMB server is running in the local network."));
 		break;
-		
+
+	case GNOME_VFS_ERROR_CANCELLED:
+		g_free (uri_for_display);
+		return;
+
 	case GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE:
 	default:
 		error_message = g_strdup_printf (_("Nautilus cannot display \"%s\"."),
@@ -1665,6 +1679,7 @@ nautilus_window_reload (NautilusWindow *window)
 {
 	char *location;
         char *current_pos;
+	GList *selection;
 	
         g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
@@ -1677,11 +1692,15 @@ nautilus_window_reload (NautilusWindow *window)
 	 */
 	location = g_strdup (window->details->location);
 	current_pos = NULL;
-	if (window->content_view != NULL)
+	selection = NULL;
+	if (window->content_view != NULL) {
 		current_pos = nautilus_view_get_first_visible_file (window->content_view);
+		selection = nautilus_view_get_selection (window->content_view);
+	}
 	begin_location_change
-		(window, location, NULL,
+		(window, location, selection,
 		 NAUTILUS_LOCATION_CHANGE_RELOAD, 0, current_pos);
         g_free (current_pos);
 	g_free (location);
+	eel_g_list_free_deep (selection);
 }
