@@ -105,6 +105,8 @@ enum {
 
 enum {
 	GO_UP,
+	RELOAD,
+	PROMPT_FOR_LOCATION,
 	LAST_SIGNAL
 };
 
@@ -158,10 +160,10 @@ nautilus_window_init (NautilusWindow *window)
 	window->details->statusbar = statusbar;
 	gtk_table_attach (GTK_TABLE (table),
 			  statusbar,
-			  /* X direction */       /* Y direction */
-			  0, 1,                   4, 5,
-			  GTK_EXPAND | GTK_FILL,  0,
-			  0,                      0);
+			  /* X direction */                   /* Y direction */
+			  0, 1,                               4, 5,
+			  GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0,
+			  0,                                  0);
 	window->details->help_message_cid = gtk_statusbar_get_context_id
 		(GTK_STATUSBAR (statusbar), "help_message");
 	gtk_widget_show (statusbar);
@@ -173,10 +175,10 @@ nautilus_window_init (NautilusWindow *window)
 	gtk_widget_show (menu);
 	gtk_table_attach (GTK_TABLE (table),
 			  menu, 
-			  /* X direction */          /* Y direction */
-			  0, 1,                      0, 1,
-			  GTK_EXPAND | GTK_FILL,     0,
-			  0,                         0);
+			  /* X direction */                   /* Y direction */
+			  0, 1,                               0, 1,
+			  GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0,
+			  0,                                  0);
 
 	
 	/* Register IconFactory callback to update the window border icon
@@ -198,6 +200,8 @@ nautilus_window_init (NautilusWindow *window)
 static void
 nautilus_window_ui_update (NautilusWindow *window)
 {
+	g_assert (NAUTILUS_IS_WINDOW (window));
+
 	gtk_ui_manager_ensure_update (window->details->ui_manager);
 }
 
@@ -216,6 +220,8 @@ nautilus_window_clear_status (gpointer callback_data)
 void
 nautilus_window_set_status (NautilusWindow *window, const char *text)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (text != NULL && text[0] != '\0') {
 		gtk_statusbar_push (GTK_STATUSBAR (window->details->statusbar), 0, text);
 	} else {
@@ -226,6 +232,8 @@ nautilus_window_set_status (NautilusWindow *window, const char *text)
 void
 nautilus_window_go_to (NautilusWindow *window, const char *uri)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	nautilus_window_open_location (window, uri, FALSE);
 }
 
@@ -233,6 +241,8 @@ nautilus_window_go_to (NautilusWindow *window, const char *uri)
 void
 nautilus_window_go_to_with_selection (NautilusWindow *window, const char *uri, GList *new_selection)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	nautilus_window_open_location_with_selection (window, uri, new_selection, FALSE);
 }
 
@@ -252,7 +262,9 @@ nautilus_window_go_up (NautilusWindow *window, gboolean close_behind)
 	GnomeVFSURI *parent_uri;
 	GList *selection;
 	char *parent_uri_string;
-	
+
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (window->details->location == NULL) {
 		return;
 	}
@@ -295,6 +307,8 @@ real_set_allow_up (NautilusWindow *window,
 void
 nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
 			 set_allow_up, (window, allow));
 }
@@ -354,6 +368,8 @@ nautilus_window_go_home (NautilusWindow *window)
 {
 	char *home_uri;
 
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	home_uri = gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
 	
 	g_assert (home_uri != NULL);
@@ -364,7 +380,7 @@ nautilus_window_go_home (NautilusWindow *window)
 void
 nautilus_window_prompt_for_location (NautilusWindow *window)
 {
-	g_assert (NAUTILUS_IS_WINDOW (window));
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
                          prompt_for_location, (window));
@@ -381,6 +397,8 @@ nautilus_window_get_location (NautilusWindow *window)
 void
 nautilus_window_zoom_in (NautilusWindow *window)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (window->content_view != NULL) {
 		nautilus_view_bump_zoom_level (window->content_view, 1);
 	}
@@ -398,6 +416,8 @@ nautilus_window_zoom_to_level (NautilusWindow *window,
 void
 nautilus_window_zoom_out (NautilusWindow *window)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (window->content_view != NULL) {
 		nautilus_view_bump_zoom_level (window->content_view, -1);
 	}
@@ -406,6 +426,8 @@ nautilus_window_zoom_out (NautilusWindow *window)
 void
 nautilus_window_zoom_to_default (NautilusWindow *window)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (window->content_view != NULL) {
 		nautilus_view_restore_default_zoom_level (window->content_view);
 	}
@@ -488,6 +510,8 @@ nautilus_window_set_initial_window_geometry (NautilusWindow *window)
 void
 nautilus_window_constructed (NautilusWindow *window)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	nautilus_window_set_initial_window_geometry (window);
 	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));
 }
@@ -1004,7 +1028,9 @@ void
 nautilus_window_display_error (NautilusWindow *window, const char *error_msg)
 {
 	GtkWidget *dialog;
-	
+
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	dialog = gtk_message_dialog_new (GTK_WINDOW (window), 0, GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_OK, error_msg, NULL);
 	gtk_widget_show (dialog);
@@ -1053,7 +1079,7 @@ real_set_title (NautilusWindow *window,
 	g_free (window->details->title);
         window->details->title = g_strdup (title);
 
-        if (window->details->title [0] != '\0' && window->current_location_bookmark &&
+        if (eel_strlen (window->details->title) > 0 && window->current_location_bookmark &&
             nautilus_bookmark_set_name (window->current_location_bookmark, window->details->title)) {
                 /* Name of item in history list changed, tell listeners. */
                 nautilus_send_history_list_changed ();
@@ -1071,6 +1097,8 @@ static void
 nautilus_window_set_title (NautilusWindow *window, 
 			   const char *title)
 {
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
 	if (window->details->title != NULL
 	    && strcmp (title, window->details->title) == 0) {
 		return;
@@ -1092,6 +1120,8 @@ void
 nautilus_window_update_title (NautilusWindow *window)
 {
 	char *title;
+
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	
 	title = nautilus_window_get_title (window);
 	nautilus_window_set_title (window, title);
@@ -1109,15 +1139,12 @@ nautilus_window_update_title (NautilusWindow *window)
 void
 nautilus_window_update_icon (NautilusWindow *window)
 {
-	char *icon_name = NULL;
+	char *icon_name;
 
-	/* Desktop window special icon */
-	if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		icon_name = g_strdup ("gnome-fs-desktop");
-	} else {
-		icon_name = nautilus_icon_factory_get_icon_for_file (window->details->viewed_file,
-								     FALSE);
-	}
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
+	icon_name = EEL_CALL_METHOD_WITH_RETURN_VALUE (NAUTILUS_WINDOW_CLASS, window,
+						       get_icon_name, (window));
 
 	if (icon_name != NULL) {
 		gtk_window_set_icon_name (GTK_WINDOW (window), icon_name);
@@ -1168,7 +1195,7 @@ void
 nautilus_window_set_content_view_widget (NautilusWindow *window,
 					 NautilusView *frame)
 {
-	g_assert (NAUTILUS_IS_WINDOW (window));
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 	
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
                          set_content_view_widget, (window, frame));
@@ -1196,6 +1223,8 @@ nautilus_window_show (GtkWidget *widget)
 GtkUIManager *
 nautilus_window_get_ui_manager (NautilusWindow *window)
 {
+	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), NULL);
+
 	return window->details->ui_manager;
 }
 
@@ -1332,7 +1361,7 @@ real_add_current_location_to_history_list (NautilusWindow *window)
 void
 nautilus_window_add_current_location_to_history_list (NautilusWindow *window)
 {
-        g_assert (NAUTILUS_IS_WINDOW (window));
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
                          add_current_location_to_history_list, (window));
@@ -1396,6 +1425,8 @@ nautilus_window_get_history (NautilusWindow *window)
 static NautilusWindowType
 nautilus_window_get_window_type (NautilusWindow *window)
 {
+	g_return_val_if_fail (NAUTILUS_IS_WINDOW (window), NAUTILUS_WINDOW_SPATIAL);
+
 	return NAUTILUS_WINDOW_GET_CLASS (window)->window_type;
 }
 
@@ -1497,11 +1528,32 @@ nautilus_window_class_init (NautilusWindowClass *class)
 			      g_signal_accumulator_true_handled, NULL,
 			      eel_marshal_BOOLEAN__BOOLEAN,
 			      G_TYPE_BOOLEAN, 1, G_TYPE_BOOLEAN);
+	signals[RELOAD] =
+		g_signal_new ("reload",
+			      G_TYPE_FROM_CLASS (class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			      G_STRUCT_OFFSET (NautilusWindowClass, reload),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
+	signals[PROMPT_FOR_LOCATION] =
+		g_signal_new ("prompt-for-location",
+			      G_TYPE_FROM_CLASS (class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			      G_STRUCT_OFFSET (NautilusWindowClass, prompt_for_location),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 	
 	binding_set = gtk_binding_set_by_class (class);
 	gtk_binding_entry_add_signal (binding_set, GDK_BackSpace, 0,
 				      "go_up", 1,
 				      G_TYPE_BOOLEAN, FALSE);
+	gtk_binding_entry_add_signal (binding_set, GDK_F5, 0,
+				      "reload", 0);
+	gtk_binding_entry_add_signal (binding_set, GDK_d, GDK_MOD1_MASK,
+				      "prompt-for-location", 0);
 
+	class->reload = nautilus_window_reload;
 	class->go_up = nautilus_window_go_up_signal;
 }
